"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.common.criteria_pb2
import google.ads.google_ads.v4.proto.common.extensions_pb2
import google.ads.google_ads.v4.proto.enums.extension_type_pb2
import google.ads.google_ads.v4.proto.enums.feed_item_status_pb2
import google.ads.google_ads.v4.proto.enums.feed_item_target_device_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ExtensionFeedItem(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    EXTENSION_TYPE_FIELD_NUMBER: builtins.int
    START_DATE_TIME_FIELD_NUMBER: builtins.int
    END_DATE_TIME_FIELD_NUMBER: builtins.int
    AD_SCHEDULES_FIELD_NUMBER: builtins.int
    DEVICE_FIELD_NUMBER: builtins.int
    TARGETED_GEO_TARGET_CONSTANT_FIELD_NUMBER: builtins.int
    TARGETED_KEYWORD_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    SITELINK_FEED_ITEM_FIELD_NUMBER: builtins.int
    STRUCTURED_SNIPPET_FEED_ITEM_FIELD_NUMBER: builtins.int
    APP_FEED_ITEM_FIELD_NUMBER: builtins.int
    CALL_FEED_ITEM_FIELD_NUMBER: builtins.int
    CALLOUT_FEED_ITEM_FIELD_NUMBER: builtins.int
    TEXT_MESSAGE_FEED_ITEM_FIELD_NUMBER: builtins.int
    PRICE_FEED_ITEM_FIELD_NUMBER: builtins.int
    PROMOTION_FEED_ITEM_FIELD_NUMBER: builtins.int
    LOCATION_FEED_ITEM_FIELD_NUMBER: builtins.int
    AFFILIATE_LOCATION_FEED_ITEM_FIELD_NUMBER: builtins.int
    HOTEL_CALLOUT_FEED_ITEM_FIELD_NUMBER: builtins.int
    TARGETED_CAMPAIGN_FIELD_NUMBER: builtins.int
    TARGETED_AD_GROUP_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    extension_type: google.ads.google_ads.v4.proto.enums.extension_type_pb2.ExtensionTypeEnum.ExtensionType.V = (
        ...
    )
    device: google.ads.google_ads.v4.proto.enums.feed_item_target_device_pb2.FeedItemTargetDeviceEnum.FeedItemTargetDevice.V = (
        ...
    )
    status: google.ads.google_ads.v4.proto.enums.feed_item_status_pb2.FeedItemStatusEnum.FeedItemStatus.V = (
        ...
    )
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def start_date_time(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def end_date_time(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def ad_schedules(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v4.proto.common.criteria_pb2.AdScheduleInfo
    ]: ...
    @property
    def targeted_geo_target_constant(
        self,
    ) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def targeted_keyword(
        self,
    ) -> google.ads.google_ads.v4.proto.common.criteria_pb2.KeywordInfo: ...
    @property
    def sitelink_feed_item(
        self,
    ) -> google.ads.google_ads.v4.proto.common.extensions_pb2.SitelinkFeedItem: ...
    @property
    def structured_snippet_feed_item(
        self,
    ) -> google.ads.google_ads.v4.proto.common.extensions_pb2.StructuredSnippetFeedItem: ...
    @property
    def app_feed_item(
        self,
    ) -> google.ads.google_ads.v4.proto.common.extensions_pb2.AppFeedItem: ...
    @property
    def call_feed_item(
        self,
    ) -> google.ads.google_ads.v4.proto.common.extensions_pb2.CallFeedItem: ...
    @property
    def callout_feed_item(
        self,
    ) -> google.ads.google_ads.v4.proto.common.extensions_pb2.CalloutFeedItem: ...
    @property
    def text_message_feed_item(
        self,
    ) -> google.ads.google_ads.v4.proto.common.extensions_pb2.TextMessageFeedItem: ...
    @property
    def price_feed_item(
        self,
    ) -> google.ads.google_ads.v4.proto.common.extensions_pb2.PriceFeedItem: ...
    @property
    def promotion_feed_item(
        self,
    ) -> google.ads.google_ads.v4.proto.common.extensions_pb2.PromotionFeedItem: ...
    @property
    def location_feed_item(
        self,
    ) -> google.ads.google_ads.v4.proto.common.extensions_pb2.LocationFeedItem: ...
    @property
    def affiliate_location_feed_item(
        self,
    ) -> google.ads.google_ads.v4.proto.common.extensions_pb2.AffiliateLocationFeedItem: ...
    @property
    def hotel_callout_feed_item(
        self,
    ) -> google.ads.google_ads.v4.proto.common.extensions_pb2.HotelCalloutFeedItem: ...
    @property
    def targeted_campaign(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def targeted_ad_group(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        extension_type: google.ads.google_ads.v4.proto.enums.extension_type_pb2.ExtensionTypeEnum.ExtensionType.V = ...,
        start_date_time: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        end_date_time: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        ad_schedules: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.common.criteria_pb2.AdScheduleInfo
            ]
        ] = ...,
        device: google.ads.google_ads.v4.proto.enums.feed_item_target_device_pb2.FeedItemTargetDeviceEnum.FeedItemTargetDevice.V = ...,
        targeted_geo_target_constant: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        targeted_keyword: typing.Optional[
            google.ads.google_ads.v4.proto.common.criteria_pb2.KeywordInfo
        ] = ...,
        status: google.ads.google_ads.v4.proto.enums.feed_item_status_pb2.FeedItemStatusEnum.FeedItemStatus.V = ...,
        sitelink_feed_item: typing.Optional[
            google.ads.google_ads.v4.proto.common.extensions_pb2.SitelinkFeedItem
        ] = ...,
        structured_snippet_feed_item: typing.Optional[
            google.ads.google_ads.v4.proto.common.extensions_pb2.StructuredSnippetFeedItem
        ] = ...,
        app_feed_item: typing.Optional[
            google.ads.google_ads.v4.proto.common.extensions_pb2.AppFeedItem
        ] = ...,
        call_feed_item: typing.Optional[
            google.ads.google_ads.v4.proto.common.extensions_pb2.CallFeedItem
        ] = ...,
        callout_feed_item: typing.Optional[
            google.ads.google_ads.v4.proto.common.extensions_pb2.CalloutFeedItem
        ] = ...,
        text_message_feed_item: typing.Optional[
            google.ads.google_ads.v4.proto.common.extensions_pb2.TextMessageFeedItem
        ] = ...,
        price_feed_item: typing.Optional[
            google.ads.google_ads.v4.proto.common.extensions_pb2.PriceFeedItem
        ] = ...,
        promotion_feed_item: typing.Optional[
            google.ads.google_ads.v4.proto.common.extensions_pb2.PromotionFeedItem
        ] = ...,
        location_feed_item: typing.Optional[
            google.ads.google_ads.v4.proto.common.extensions_pb2.LocationFeedItem
        ] = ...,
        affiliate_location_feed_item: typing.Optional[
            google.ads.google_ads.v4.proto.common.extensions_pb2.AffiliateLocationFeedItem
        ] = ...,
        hotel_callout_feed_item: typing.Optional[
            google.ads.google_ads.v4.proto.common.extensions_pb2.HotelCalloutFeedItem
        ] = ...,
        targeted_campaign: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        targeted_ad_group: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "affiliate_location_feed_item",
            b"affiliate_location_feed_item",
            "app_feed_item",
            b"app_feed_item",
            "call_feed_item",
            b"call_feed_item",
            "callout_feed_item",
            b"callout_feed_item",
            "end_date_time",
            b"end_date_time",
            "extension",
            b"extension",
            "hotel_callout_feed_item",
            b"hotel_callout_feed_item",
            "id",
            b"id",
            "location_feed_item",
            b"location_feed_item",
            "price_feed_item",
            b"price_feed_item",
            "promotion_feed_item",
            b"promotion_feed_item",
            "serving_resource_targeting",
            b"serving_resource_targeting",
            "sitelink_feed_item",
            b"sitelink_feed_item",
            "start_date_time",
            b"start_date_time",
            "structured_snippet_feed_item",
            b"structured_snippet_feed_item",
            "targeted_ad_group",
            b"targeted_ad_group",
            "targeted_campaign",
            b"targeted_campaign",
            "targeted_geo_target_constant",
            b"targeted_geo_target_constant",
            "targeted_keyword",
            b"targeted_keyword",
            "text_message_feed_item",
            b"text_message_feed_item",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "ad_schedules",
            b"ad_schedules",
            "affiliate_location_feed_item",
            b"affiliate_location_feed_item",
            "app_feed_item",
            b"app_feed_item",
            "call_feed_item",
            b"call_feed_item",
            "callout_feed_item",
            b"callout_feed_item",
            "device",
            b"device",
            "end_date_time",
            b"end_date_time",
            "extension",
            b"extension",
            "extension_type",
            b"extension_type",
            "hotel_callout_feed_item",
            b"hotel_callout_feed_item",
            "id",
            b"id",
            "location_feed_item",
            b"location_feed_item",
            "price_feed_item",
            b"price_feed_item",
            "promotion_feed_item",
            b"promotion_feed_item",
            "resource_name",
            b"resource_name",
            "serving_resource_targeting",
            b"serving_resource_targeting",
            "sitelink_feed_item",
            b"sitelink_feed_item",
            "start_date_time",
            b"start_date_time",
            "status",
            b"status",
            "structured_snippet_feed_item",
            b"structured_snippet_feed_item",
            "targeted_ad_group",
            b"targeted_ad_group",
            "targeted_campaign",
            b"targeted_campaign",
            "targeted_geo_target_constant",
            b"targeted_geo_target_constant",
            "targeted_keyword",
            b"targeted_keyword",
            "text_message_feed_item",
            b"text_message_feed_item",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["extension", b"extension"]
    ) -> typing_extensions.Literal[
        "sitelink_feed_item",
        "structured_snippet_feed_item",
        "app_feed_item",
        "call_feed_item",
        "callout_feed_item",
        "text_message_feed_item",
        "price_feed_item",
        "promotion_feed_item",
        "location_feed_item",
        "affiliate_location_feed_item",
        "hotel_callout_feed_item",
    ]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "serving_resource_targeting", b"serving_resource_targeting"
        ],
    ) -> typing_extensions.Literal["targeted_campaign", "targeted_ad_group"]: ...

global___ExtensionFeedItem = ExtensionFeedItem



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CustomAudienceErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CustomAudienceError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CustomAudienceError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CustomAudienceErrorEnum.CustomAudienceError.V(0)
        UNKNOWN = CustomAudienceErrorEnum.CustomAudienceError.V(1)
        NAME_ALREADY_USED = CustomAudienceErrorEnum.CustomAudienceError.V(2)
        CANNOT_REMOVE_WHILE_IN_USE = CustomAudienceErrorEnum.CustomAudienceError.V(3)
        RESOURCE_ALREADY_REMOVED = CustomAudienceErrorEnum.CustomAudienceError.V(4)
        MEMBER_TYPE_AND_PARAMETER_ALREADY_EXISTED = (
            CustomAudienceErrorEnum.CustomAudienceError.V(5)
        )
        INVALID_MEMBER_TYPE = CustomAudienceErrorEnum.CustomAudienceError.V(6)
        MEMBER_TYPE_AND_VALUE_DOES_NOT_MATCH = (
            CustomAudienceErrorEnum.CustomAudienceError.V(7)
        )
        POLICY_VIOLATION = CustomAudienceErrorEnum.CustomAudienceError.V(8)
        INVALID_TYPE_CHANGE = CustomAudienceErrorEnum.CustomAudienceError.V(9)
    class CustomAudienceError(metaclass=_CustomAudienceError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CustomAudienceErrorEnum.CustomAudienceError.V(0)
    UNKNOWN = CustomAudienceErrorEnum.CustomAudienceError.V(1)
    NAME_ALREADY_USED = CustomAudienceErrorEnum.CustomAudienceError.V(2)
    CANNOT_REMOVE_WHILE_IN_USE = CustomAudienceErrorEnum.CustomAudienceError.V(3)
    RESOURCE_ALREADY_REMOVED = CustomAudienceErrorEnum.CustomAudienceError.V(4)
    MEMBER_TYPE_AND_PARAMETER_ALREADY_EXISTED = (
        CustomAudienceErrorEnum.CustomAudienceError.V(5)
    )
    INVALID_MEMBER_TYPE = CustomAudienceErrorEnum.CustomAudienceError.V(6)
    MEMBER_TYPE_AND_VALUE_DOES_NOT_MATCH = (
        CustomAudienceErrorEnum.CustomAudienceError.V(7)
    )
    POLICY_VIOLATION = CustomAudienceErrorEnum.CustomAudienceError.V(8)
    INVALID_TYPE_CHANGE = CustomAudienceErrorEnum.CustomAudienceError.V(9)
    def __init__(
        self,
    ) -> None: ...

global___CustomAudienceErrorEnum = CustomAudienceErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BiddingSourceEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _BiddingSource(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[BiddingSource.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = BiddingSourceEnum.BiddingSource.V(0)
        UNKNOWN = BiddingSourceEnum.BiddingSource.V(1)
        CAMPAIGN_BIDDING_STRATEGY = BiddingSourceEnum.BiddingSource.V(5)
        AD_GROUP = BiddingSourceEnum.BiddingSource.V(6)
        AD_GROUP_CRITERION = BiddingSourceEnum.BiddingSource.V(7)
    class BiddingSource(metaclass=_BiddingSource):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = BiddingSourceEnum.BiddingSource.V(0)
    UNKNOWN = BiddingSourceEnum.BiddingSource.V(1)
    CAMPAIGN_BIDDING_STRATEGY = BiddingSourceEnum.BiddingSource.V(5)
    AD_GROUP = BiddingSourceEnum.BiddingSource.V(6)
    AD_GROUP_CRITERION = BiddingSourceEnum.BiddingSource.V(7)
    def __init__(
        self,
    ) -> None: ...

global___BiddingSourceEnum = BiddingSourceEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LeadFormCallToActionTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _LeadFormCallToActionType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            LeadFormCallToActionType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(0)
        UNKNOWN = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(1)
        LEARN_MORE = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(2)
        GET_QUOTE = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(3)
        APPLY_NOW = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(4)
        SIGN_UP = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(5)
        CONTACT_US = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(6)
        SUBSCRIBE = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(7)
        DOWNLOAD = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(8)
        BOOK_NOW = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(9)
        GET_OFFER = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(10)
        REGISTER = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(11)
        GET_INFO = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(12)
        REQUEST_DEMO = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(13)
        JOIN_NOW = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(14)
        GET_STARTED = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(15)
    class LeadFormCallToActionType(metaclass=_LeadFormCallToActionType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(0)
    UNKNOWN = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(1)
    LEARN_MORE = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(2)
    GET_QUOTE = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(3)
    APPLY_NOW = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(4)
    SIGN_UP = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(5)
    CONTACT_US = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(6)
    SUBSCRIBE = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(7)
    DOWNLOAD = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(8)
    BOOK_NOW = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(9)
    GET_OFFER = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(10)
    REGISTER = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(11)
    GET_INFO = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(12)
    REQUEST_DEMO = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(13)
    JOIN_NOW = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(14)
    GET_STARTED = LeadFormCallToActionTypeEnum.LeadFormCallToActionType.V(15)
    def __init__(
        self,
    ) -> None: ...

global___LeadFormCallToActionTypeEnum = LeadFormCallToActionTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.advertising_channel_sub_type_pb2
import google.ads.google_ads.v4.proto.enums.advertising_channel_type_pb2
import google.ads.google_ads.v4.proto.enums.criterion_category_channel_availability_mode_pb2
import google.ads.google_ads.v4.proto.enums.criterion_category_locale_availability_mode_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CriterionCategoryAvailability(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CHANNEL_FIELD_NUMBER: builtins.int
    LOCALE_FIELD_NUMBER: builtins.int
    @property
    def channel(self) -> global___CriterionCategoryChannelAvailability: ...
    @property
    def locale(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CriterionCategoryLocaleAvailability
    ]: ...
    def __init__(
        self,
        *,
        channel: typing.Optional[global___CriterionCategoryChannelAvailability] = ...,
        locale: typing.Optional[
            typing.Iterable[global___CriterionCategoryLocaleAvailability]
        ] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["channel", b"channel"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "channel", b"channel", "locale", b"locale"
        ],
    ) -> None: ...

global___CriterionCategoryAvailability = CriterionCategoryAvailability

class CriterionCategoryChannelAvailability(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AVAILABILITY_MODE_FIELD_NUMBER: builtins.int
    ADVERTISING_CHANNEL_TYPE_FIELD_NUMBER: builtins.int
    ADVERTISING_CHANNEL_SUB_TYPE_FIELD_NUMBER: builtins.int
    INCLUDE_DEFAULT_CHANNEL_SUB_TYPE_FIELD_NUMBER: builtins.int
    availability_mode: google.ads.google_ads.v4.proto.enums.criterion_category_channel_availability_mode_pb2.CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V = (
        ...
    )
    advertising_channel_type: google.ads.google_ads.v4.proto.enums.advertising_channel_type_pb2.AdvertisingChannelTypeEnum.AdvertisingChannelType.V = (
        ...
    )
    advertising_channel_sub_type: google.protobuf.internal.containers.RepeatedScalarFieldContainer[
        google.ads.google_ads.v4.proto.enums.advertising_channel_sub_type_pb2.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V
    ] = ...
    @property
    def include_default_channel_sub_type(
        self,
    ) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        availability_mode: google.ads.google_ads.v4.proto.enums.criterion_category_channel_availability_mode_pb2.CriterionCategoryChannelAvailabilityModeEnum.CriterionCategoryChannelAvailabilityMode.V = ...,
        advertising_channel_type: google.ads.google_ads.v4.proto.enums.advertising_channel_type_pb2.AdvertisingChannelTypeEnum.AdvertisingChannelType.V = ...,
        advertising_channel_sub_type: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v4.proto.enums.advertising_channel_sub_type_pb2.AdvertisingChannelSubTypeEnum.AdvertisingChannelSubType.V
            ]
        ] = ...,
        include_default_channel_sub_type: typing.Optional[
            google.protobuf.wrappers_pb2.BoolValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "include_default_channel_sub_type", b"include_default_channel_sub_type"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "advertising_channel_sub_type",
            b"advertising_channel_sub_type",
            "advertising_channel_type",
            b"advertising_channel_type",
            "availability_mode",
            b"availability_mode",
            "include_default_channel_sub_type",
            b"include_default_channel_sub_type",
        ],
    ) -> None: ...

global___CriterionCategoryChannelAvailability = CriterionCategoryChannelAvailability

class CriterionCategoryLocaleAvailability(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    AVAILABILITY_MODE_FIELD_NUMBER: builtins.int
    COUNTRY_CODE_FIELD_NUMBER: builtins.int
    LANGUAGE_CODE_FIELD_NUMBER: builtins.int
    availability_mode: google.ads.google_ads.v4.proto.enums.criterion_category_locale_availability_mode_pb2.CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V = (
        ...
    )
    @property
    def country_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def language_code(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        availability_mode: google.ads.google_ads.v4.proto.enums.criterion_category_locale_availability_mode_pb2.CriterionCategoryLocaleAvailabilityModeEnum.CriterionCategoryLocaleAvailabilityMode.V = ...,
        country_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        language_code: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "country_code", b"country_code", "language_code", b"language_code"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "availability_mode",
            b"availability_mode",
            "country_code",
            b"country_code",
            "language_code",
            b"language_code",
        ],
    ) -> None: ...

global___CriterionCategoryLocaleAvailability = CriterionCategoryLocaleAvailability



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class LocationPlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _LocationPlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            LocationPlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(0)
        UNKNOWN = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(1)
        BUSINESS_NAME = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(2)
        ADDRESS_LINE_1 = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(3)
        ADDRESS_LINE_2 = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(4)
        CITY = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(5)
        PROVINCE = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(6)
        POSTAL_CODE = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(7)
        COUNTRY_CODE = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(8)
        PHONE_NUMBER = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(9)
    class LocationPlaceholderField(metaclass=_LocationPlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(0)
    UNKNOWN = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(1)
    BUSINESS_NAME = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(2)
    ADDRESS_LINE_1 = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(3)
    ADDRESS_LINE_2 = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(4)
    CITY = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(5)
    PROVINCE = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(6)
    POSTAL_CODE = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(7)
    COUNTRY_CODE = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(8)
    PHONE_NUMBER = LocationPlaceholderFieldEnum.LocationPlaceholderField.V(9)
    def __init__(
        self,
    ) -> None: ...

global___LocationPlaceholderFieldEnum = LocationPlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ImagePlaceholderFieldEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ImagePlaceholderField(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ImagePlaceholderField.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = ImagePlaceholderFieldEnum.ImagePlaceholderField.V(0)
        UNKNOWN = ImagePlaceholderFieldEnum.ImagePlaceholderField.V(1)
        ASSET_ID = ImagePlaceholderFieldEnum.ImagePlaceholderField.V(2)
    class ImagePlaceholderField(metaclass=_ImagePlaceholderField):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ImagePlaceholderFieldEnum.ImagePlaceholderField.V(0)
    UNKNOWN = ImagePlaceholderFieldEnum.ImagePlaceholderField.V(1)
    ASSET_ID = ImagePlaceholderFieldEnum.ImagePlaceholderField.V(2)
    def __init__(
        self,
    ) -> None: ...

global___ImagePlaceholderFieldEnum = ImagePlaceholderFieldEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedMappingErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedMappingError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[FeedMappingError.V],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedMappingErrorEnum.FeedMappingError.V(0)
        UNKNOWN = FeedMappingErrorEnum.FeedMappingError.V(1)
        INVALID_PLACEHOLDER_FIELD = FeedMappingErrorEnum.FeedMappingError.V(2)
        INVALID_CRITERION_FIELD = FeedMappingErrorEnum.FeedMappingError.V(3)
        INVALID_PLACEHOLDER_TYPE = FeedMappingErrorEnum.FeedMappingError.V(4)
        INVALID_CRITERION_TYPE = FeedMappingErrorEnum.FeedMappingError.V(5)
        NO_ATTRIBUTE_FIELD_MAPPINGS = FeedMappingErrorEnum.FeedMappingError.V(7)
        FEED_ATTRIBUTE_TYPE_MISMATCH = FeedMappingErrorEnum.FeedMappingError.V(8)
        CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED = (
            FeedMappingErrorEnum.FeedMappingError.V(9)
        )
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE = (
            FeedMappingErrorEnum.FeedMappingError.V(10)
        )
        MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE = FeedMappingErrorEnum.FeedMappingError.V(
            11
        )
        MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD = (
            FeedMappingErrorEnum.FeedMappingError.V(12)
        )
        MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD = FeedMappingErrorEnum.FeedMappingError.V(
            13
        )
        UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS = FeedMappingErrorEnum.FeedMappingError.V(
            14
        )
        LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS = (
            FeedMappingErrorEnum.FeedMappingError.V(15)
        )
        CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED = FeedMappingErrorEnum.FeedMappingError.V(
            16
        )
        INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED = (
            FeedMappingErrorEnum.FeedMappingError.V(17)
        )
        INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE = (
            FeedMappingErrorEnum.FeedMappingError.V(18)
        )
        ATTRIBUTE_FIELD_MAPPING_MISSING_FIELD = FeedMappingErrorEnum.FeedMappingError.V(
            19
        )
    class FeedMappingError(metaclass=_FeedMappingError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedMappingErrorEnum.FeedMappingError.V(0)
    UNKNOWN = FeedMappingErrorEnum.FeedMappingError.V(1)
    INVALID_PLACEHOLDER_FIELD = FeedMappingErrorEnum.FeedMappingError.V(2)
    INVALID_CRITERION_FIELD = FeedMappingErrorEnum.FeedMappingError.V(3)
    INVALID_PLACEHOLDER_TYPE = FeedMappingErrorEnum.FeedMappingError.V(4)
    INVALID_CRITERION_TYPE = FeedMappingErrorEnum.FeedMappingError.V(5)
    NO_ATTRIBUTE_FIELD_MAPPINGS = FeedMappingErrorEnum.FeedMappingError.V(7)
    FEED_ATTRIBUTE_TYPE_MISMATCH = FeedMappingErrorEnum.FeedMappingError.V(8)
    CANNOT_OPERATE_ON_MAPPINGS_FOR_SYSTEM_GENERATED_FEED = (
        FeedMappingErrorEnum.FeedMappingError.V(9)
    )
    MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_TYPE = FeedMappingErrorEnum.FeedMappingError.V(10)
    MULTIPLE_MAPPINGS_FOR_CRITERION_TYPE = FeedMappingErrorEnum.FeedMappingError.V(11)
    MULTIPLE_MAPPINGS_FOR_PLACEHOLDER_FIELD = FeedMappingErrorEnum.FeedMappingError.V(
        12
    )
    MULTIPLE_MAPPINGS_FOR_CRITERION_FIELD = FeedMappingErrorEnum.FeedMappingError.V(13)
    UNEXPECTED_ATTRIBUTE_FIELD_MAPPINGS = FeedMappingErrorEnum.FeedMappingError.V(14)
    LOCATION_PLACEHOLDER_ONLY_FOR_PLACES_FEEDS = (
        FeedMappingErrorEnum.FeedMappingError.V(15)
    )
    CANNOT_MODIFY_MAPPINGS_FOR_TYPED_FEED = FeedMappingErrorEnum.FeedMappingError.V(16)
    INVALID_PLACEHOLDER_TYPE_FOR_NON_SYSTEM_GENERATED_FEED = (
        FeedMappingErrorEnum.FeedMappingError.V(17)
    )
    INVALID_PLACEHOLDER_TYPE_FOR_SYSTEM_GENERATED_FEED_TYPE = (
        FeedMappingErrorEnum.FeedMappingError.V(18)
    )
    ATTRIBUTE_FIELD_MAPPING_MISSING_FIELD = FeedMappingErrorEnum.FeedMappingError.V(19)
    def __init__(
        self,
    ) -> None: ...

global___FeedMappingErrorEnum = FeedMappingErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class OperatingSystemVersionOperatorTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _OperatingSystemVersionOperatorType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            OperatingSystemVersionOperatorType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(
                0
            )
        )
        UNKNOWN = (
            OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(
                1
            )
        )
        EQUALS_TO = (
            OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(
                2
            )
        )
        GREATER_THAN_EQUALS_TO = (
            OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(
                4
            )
        )
    class OperatingSystemVersionOperatorType(
        metaclass=_OperatingSystemVersionOperatorType
    ):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = (
        OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(0)
    )
    UNKNOWN = (
        OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(1)
    )
    EQUALS_TO = (
        OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(2)
    )
    GREATER_THAN_EQUALS_TO = (
        OperatingSystemVersionOperatorTypeEnum.OperatingSystemVersionOperatorType.V(4)
    )
    def __init__(
        self,
    ) -> None: ...

global___OperatingSystemVersionOperatorTypeEnum = OperatingSystemVersionOperatorTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class BidModifierSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___BidModifierSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[
            typing.Iterable[global___BidModifierSimulationPoint]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___BidModifierSimulationPointList = BidModifierSimulationPointList

class CpcBidSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CpcBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[typing.Iterable[global___CpcBidSimulationPoint]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___CpcBidSimulationPointList = CpcBidSimulationPointList

class CpvBidSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___CpvBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[typing.Iterable[global___CpvBidSimulationPoint]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___CpvBidSimulationPointList = CpvBidSimulationPointList

class TargetCpaSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___TargetCpaSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[
            typing.Iterable[global___TargetCpaSimulationPoint]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___TargetCpaSimulationPointList = TargetCpaSimulationPointList

class TargetRoasSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___TargetRoasSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[
            typing.Iterable[global___TargetRoasSimulationPoint]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___TargetRoasSimulationPointList = TargetRoasSimulationPointList

class PercentCpcBidSimulationPointList(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    POINTS_FIELD_NUMBER: builtins.int
    @property
    def points(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___PercentCpcBidSimulationPoint
    ]: ...
    def __init__(
        self,
        *,
        points: typing.Optional[
            typing.Iterable[global___PercentCpcBidSimulationPoint]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["points", b"points"]
    ) -> None: ...

global___PercentCpcBidSimulationPointList = PercentCpcBidSimulationPointList

class BidModifierSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    BID_MODIFIER_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    PARENT_BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    PARENT_BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    PARENT_CLICKS_FIELD_NUMBER: builtins.int
    PARENT_COST_MICROS_FIELD_NUMBER: builtins.int
    PARENT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    PARENT_TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    PARENT_REQUIRED_BUDGET_MICROS_FIELD_NUMBER: builtins.int
    bid_modifier: builtins.float = ...
    biddable_conversions: builtins.float = ...
    biddable_conversions_value: builtins.float = ...
    clicks: builtins.int = ...
    cost_micros: builtins.int = ...
    impressions: builtins.int = ...
    top_slot_impressions: builtins.int = ...
    parent_biddable_conversions: builtins.float = ...
    parent_biddable_conversions_value: builtins.float = ...
    parent_clicks: builtins.int = ...
    parent_cost_micros: builtins.int = ...
    parent_impressions: builtins.int = ...
    parent_top_slot_impressions: builtins.int = ...
    parent_required_budget_micros: builtins.int = ...
    def __init__(
        self,
        *,
        bid_modifier: builtins.float = ...,
        biddable_conversions: builtins.float = ...,
        biddable_conversions_value: builtins.float = ...,
        clicks: builtins.int = ...,
        cost_micros: builtins.int = ...,
        impressions: builtins.int = ...,
        top_slot_impressions: builtins.int = ...,
        parent_biddable_conversions: builtins.float = ...,
        parent_biddable_conversions_value: builtins.float = ...,
        parent_clicks: builtins.int = ...,
        parent_cost_micros: builtins.int = ...,
        parent_impressions: builtins.int = ...,
        parent_top_slot_impressions: builtins.int = ...,
        parent_required_budget_micros: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_bid_modifier",
            b"_bid_modifier",
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_parent_biddable_conversions",
            b"_parent_biddable_conversions",
            "_parent_biddable_conversions_value",
            b"_parent_biddable_conversions_value",
            "_parent_clicks",
            b"_parent_clicks",
            "_parent_cost_micros",
            b"_parent_cost_micros",
            "_parent_impressions",
            b"_parent_impressions",
            "_parent_required_budget_micros",
            b"_parent_required_budget_micros",
            "_parent_top_slot_impressions",
            b"_parent_top_slot_impressions",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "bid_modifier",
            b"bid_modifier",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "parent_biddable_conversions",
            b"parent_biddable_conversions",
            "parent_biddable_conversions_value",
            b"parent_biddable_conversions_value",
            "parent_clicks",
            b"parent_clicks",
            "parent_cost_micros",
            b"parent_cost_micros",
            "parent_impressions",
            b"parent_impressions",
            "parent_required_budget_micros",
            b"parent_required_budget_micros",
            "parent_top_slot_impressions",
            b"parent_top_slot_impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_bid_modifier",
            b"_bid_modifier",
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_parent_biddable_conversions",
            b"_parent_biddable_conversions",
            "_parent_biddable_conversions_value",
            b"_parent_biddable_conversions_value",
            "_parent_clicks",
            b"_parent_clicks",
            "_parent_cost_micros",
            b"_parent_cost_micros",
            "_parent_impressions",
            b"_parent_impressions",
            "_parent_required_budget_micros",
            b"_parent_required_budget_micros",
            "_parent_top_slot_impressions",
            b"_parent_top_slot_impressions",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "bid_modifier",
            b"bid_modifier",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "parent_biddable_conversions",
            b"parent_biddable_conversions",
            "parent_biddable_conversions_value",
            b"parent_biddable_conversions_value",
            "parent_clicks",
            b"parent_clicks",
            "parent_cost_micros",
            b"parent_cost_micros",
            "parent_impressions",
            b"parent_impressions",
            "parent_required_budget_micros",
            b"parent_required_budget_micros",
            "parent_top_slot_impressions",
            b"parent_top_slot_impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_bid_modifier", b"_bid_modifier"]
    ) -> typing_extensions.Literal["bid_modifier"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions.Literal["biddable_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions.Literal["biddable_conversions_value"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_clicks", b"_clicks"]
    ) -> typing_extensions.Literal["clicks"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions.Literal["cost_micros"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_impressions", b"_impressions"]
    ) -> typing_extensions.Literal["impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_parent_biddable_conversions", b"_parent_biddable_conversions"
        ],
    ) -> typing_extensions.Literal["parent_biddable_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_parent_biddable_conversions_value", b"_parent_biddable_conversions_value"
        ],
    ) -> typing_extensions.Literal["parent_biddable_conversions_value"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_parent_clicks", b"_parent_clicks"],
    ) -> typing_extensions.Literal["parent_clicks"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_parent_cost_micros", b"_parent_cost_micros"
        ],
    ) -> typing_extensions.Literal["parent_cost_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_parent_impressions", b"_parent_impressions"
        ],
    ) -> typing_extensions.Literal["parent_impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_parent_required_budget_micros", b"_parent_required_budget_micros"
        ],
    ) -> typing_extensions.Literal["parent_required_budget_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_parent_top_slot_impressions", b"_parent_top_slot_impressions"
        ],
    ) -> typing_extensions.Literal["parent_top_slot_impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions.Literal["top_slot_impressions"]: ...

global___BidModifierSimulationPoint = BidModifierSimulationPoint

class CpcBidSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    cpc_bid_micros: builtins.int = ...
    biddable_conversions: builtins.float = ...
    biddable_conversions_value: builtins.float = ...
    clicks: builtins.int = ...
    cost_micros: builtins.int = ...
    impressions: builtins.int = ...
    top_slot_impressions: builtins.int = ...
    def __init__(
        self,
        *,
        cpc_bid_micros: builtins.int = ...,
        biddable_conversions: builtins.float = ...,
        biddable_conversions_value: builtins.float = ...,
        clicks: builtins.int = ...,
        cost_micros: builtins.int = ...,
        impressions: builtins.int = ...,
        top_slot_impressions: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_cpc_bid_micros",
            b"_cpc_bid_micros",
            "_impressions",
            b"_impressions",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "impressions",
            b"impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_cpc_bid_micros",
            b"_cpc_bid_micros",
            "_impressions",
            b"_impressions",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "cpc_bid_micros",
            b"cpc_bid_micros",
            "impressions",
            b"impressions",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions.Literal["biddable_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions.Literal["biddable_conversions_value"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_clicks", b"_clicks"]
    ) -> typing_extensions.Literal["clicks"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions.Literal["cost_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_cpc_bid_micros", b"_cpc_bid_micros"],
    ) -> typing_extensions.Literal["cpc_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_impressions", b"_impressions"]
    ) -> typing_extensions.Literal["impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions.Literal["top_slot_impressions"]: ...

global___CpcBidSimulationPoint = CpcBidSimulationPoint

class CpvBidSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CPV_BID_MICROS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    VIEWS_FIELD_NUMBER: builtins.int
    cpv_bid_micros: builtins.int = ...
    cost_micros: builtins.int = ...
    impressions: builtins.int = ...
    views: builtins.int = ...
    def __init__(
        self,
        *,
        cpv_bid_micros: builtins.int = ...,
        cost_micros: builtins.int = ...,
        impressions: builtins.int = ...,
        views: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_cost_micros",
            b"_cost_micros",
            "_cpv_bid_micros",
            b"_cpv_bid_micros",
            "_impressions",
            b"_impressions",
            "_views",
            b"_views",
            "cost_micros",
            b"cost_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "impressions",
            b"impressions",
            "views",
            b"views",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_cost_micros",
            b"_cost_micros",
            "_cpv_bid_micros",
            b"_cpv_bid_micros",
            "_impressions",
            b"_impressions",
            "_views",
            b"_views",
            "cost_micros",
            b"cost_micros",
            "cpv_bid_micros",
            b"cpv_bid_micros",
            "impressions",
            b"impressions",
            "views",
            b"views",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions.Literal["cost_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["_cpv_bid_micros", b"_cpv_bid_micros"],
    ) -> typing_extensions.Literal["cpv_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_impressions", b"_impressions"]
    ) -> typing_extensions.Literal["impressions"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_views", b"_views"]
    ) -> typing_extensions.Literal["views"]: ...

global___CpvBidSimulationPoint = CpvBidSimulationPoint

class TargetCpaSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_CPA_MICROS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    target_cpa_micros: builtins.int = ...
    biddable_conversions: builtins.float = ...
    biddable_conversions_value: builtins.float = ...
    clicks: builtins.int = ...
    cost_micros: builtins.int = ...
    impressions: builtins.int = ...
    top_slot_impressions: builtins.int = ...
    def __init__(
        self,
        *,
        target_cpa_micros: builtins.int = ...,
        biddable_conversions: builtins.float = ...,
        biddable_conversions_value: builtins.float = ...,
        clicks: builtins.int = ...,
        cost_micros: builtins.int = ...,
        impressions: builtins.int = ...,
        top_slot_impressions: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_cpa_micros",
            b"target_cpa_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_target_cpa_micros",
            b"_target_cpa_micros",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_cpa_micros",
            b"target_cpa_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions.Literal["biddable_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions.Literal["biddable_conversions_value"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_clicks", b"_clicks"]
    ) -> typing_extensions.Literal["clicks"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions.Literal["cost_micros"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_impressions", b"_impressions"]
    ) -> typing_extensions.Literal["impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_target_cpa_micros", b"_target_cpa_micros"
        ],
    ) -> typing_extensions.Literal["target_cpa_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions.Literal["top_slot_impressions"]: ...

global___TargetCpaSimulationPoint = TargetCpaSimulationPoint

class TargetRoasSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TARGET_ROAS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    target_roas: builtins.float = ...
    biddable_conversions: builtins.float = ...
    biddable_conversions_value: builtins.float = ...
    clicks: builtins.int = ...
    cost_micros: builtins.int = ...
    impressions: builtins.int = ...
    top_slot_impressions: builtins.int = ...
    def __init__(
        self,
        *,
        target_roas: builtins.float = ...,
        biddable_conversions: builtins.float = ...,
        biddable_conversions_value: builtins.float = ...,
        clicks: builtins.int = ...,
        cost_micros: builtins.int = ...,
        impressions: builtins.int = ...,
        top_slot_impressions: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_target_roas",
            b"_target_roas",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_roas",
            b"target_roas",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_target_roas",
            b"_target_roas",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "target_roas",
            b"target_roas",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions.Literal["biddable_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions.Literal["biddable_conversions_value"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_clicks", b"_clicks"]
    ) -> typing_extensions.Literal["clicks"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions.Literal["cost_micros"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_impressions", b"_impressions"]
    ) -> typing_extensions.Literal["impressions"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_target_roas", b"_target_roas"]
    ) -> typing_extensions.Literal["target_roas"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions.Literal["top_slot_impressions"]: ...

global___TargetRoasSimulationPoint = TargetRoasSimulationPoint

class PercentCpcBidSimulationPoint(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PERCENT_CPC_BID_MICROS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_FIELD_NUMBER: builtins.int
    BIDDABLE_CONVERSIONS_VALUE_FIELD_NUMBER: builtins.int
    CLICKS_FIELD_NUMBER: builtins.int
    COST_MICROS_FIELD_NUMBER: builtins.int
    IMPRESSIONS_FIELD_NUMBER: builtins.int
    TOP_SLOT_IMPRESSIONS_FIELD_NUMBER: builtins.int
    percent_cpc_bid_micros: builtins.int = ...
    biddable_conversions: builtins.float = ...
    biddable_conversions_value: builtins.float = ...
    clicks: builtins.int = ...
    cost_micros: builtins.int = ...
    impressions: builtins.int = ...
    top_slot_impressions: builtins.int = ...
    def __init__(
        self,
        *,
        percent_cpc_bid_micros: builtins.int = ...,
        biddable_conversions: builtins.float = ...,
        biddable_conversions_value: builtins.float = ...,
        clicks: builtins.int = ...,
        cost_micros: builtins.int = ...,
        impressions: builtins.int = ...,
        top_slot_impressions: builtins.int = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_percent_cpc_bid_micros",
            b"_percent_cpc_bid_micros",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "percent_cpc_bid_micros",
            b"percent_cpc_bid_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "_biddable_conversions",
            b"_biddable_conversions",
            "_biddable_conversions_value",
            b"_biddable_conversions_value",
            "_clicks",
            b"_clicks",
            "_cost_micros",
            b"_cost_micros",
            "_impressions",
            b"_impressions",
            "_percent_cpc_bid_micros",
            b"_percent_cpc_bid_micros",
            "_top_slot_impressions",
            b"_top_slot_impressions",
            "biddable_conversions",
            b"biddable_conversions",
            "biddable_conversions_value",
            b"biddable_conversions_value",
            "clicks",
            b"clicks",
            "cost_micros",
            b"cost_micros",
            "impressions",
            b"impressions",
            "percent_cpc_bid_micros",
            b"percent_cpc_bid_micros",
            "top_slot_impressions",
            b"top_slot_impressions",
        ],
    ) -> None: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_biddable_conversions", b"_biddable_conversions"
        ],
    ) -> typing_extensions.Literal["biddable_conversions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_biddable_conversions_value", b"_biddable_conversions_value"
        ],
    ) -> typing_extensions.Literal["biddable_conversions_value"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_clicks", b"_clicks"]
    ) -> typing_extensions.Literal["clicks"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_cost_micros", b"_cost_micros"]
    ) -> typing_extensions.Literal["cost_micros"]: ...
    @typing.overload
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["_impressions", b"_impressions"]
    ) -> typing_extensions.Literal["impressions"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_percent_cpc_bid_micros", b"_percent_cpc_bid_micros"
        ],
    ) -> typing_extensions.Literal["percent_cpc_bid_micros"]: ...
    @typing.overload
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "_top_slot_impressions", b"_top_slot_impressions"
        ],
    ) -> typing_extensions.Literal["top_slot_impressions"]: ...

global___PercentCpcBidSimulationPoint = PercentCpcBidSimulationPoint



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.resources.batch_job_pb2
import google.ads.google_ads.v5.proto.services.google_ads_service_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.rpc.status_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class MutateBatchJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CUSTOMER_ID_FIELD_NUMBER: builtins.int
    OPERATION_FIELD_NUMBER: builtins.int
    customer_id: typing.Text = ...
    @property
    def operation(self) -> global___BatchJobOperation: ...
    def __init__(
        self,
        *,
        customer_id: typing.Text = ...,
        operation: typing.Optional[global___BatchJobOperation] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["operation", b"operation"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "customer_id", b"customer_id", "operation", b"operation"
        ],
    ) -> None: ...

global___MutateBatchJobRequest = MutateBatchJobRequest

class BatchJobOperation(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CREATE_FIELD_NUMBER: builtins.int
    @property
    def create(
        self,
    ) -> google.ads.google_ads.v5.proto.resources.batch_job_pb2.BatchJob: ...
    def __init__(
        self,
        *,
        create: typing.Optional[
            google.ads.google_ads.v5.proto.resources.batch_job_pb2.BatchJob
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "create", b"create", "operation", b"operation"
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["operation", b"operation"]
    ) -> typing_extensions.Literal["create"]: ...

global___BatchJobOperation = BatchJobOperation

class MutateBatchJobResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULT_FIELD_NUMBER: builtins.int
    @property
    def result(self) -> global___MutateBatchJobResult: ...
    def __init__(
        self,
        *,
        result: typing.Optional[global___MutateBatchJobResult] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["result", b"result"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["result", b"result"]
    ) -> None: ...

global___MutateBatchJobResponse = MutateBatchJobResponse

class MutateBatchJobResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___MutateBatchJobResult = MutateBatchJobResult

class GetBatchJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___GetBatchJobRequest = GetBatchJobRequest

class RunBatchJobRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["resource_name", b"resource_name"]
    ) -> None: ...

global___RunBatchJobRequest = RunBatchJobRequest

class AddBatchJobOperationsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    SEQUENCE_TOKEN_FIELD_NUMBER: builtins.int
    MUTATE_OPERATIONS_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    sequence_token: typing.Text = ...
    @property
    def mutate_operations(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        google.ads.google_ads.v5.proto.services.google_ads_service_pb2.MutateOperation
    ]: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        sequence_token: typing.Text = ...,
        mutate_operations: typing.Optional[
            typing.Iterable[
                google.ads.google_ads.v5.proto.services.google_ads_service_pb2.MutateOperation
            ]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "mutate_operations",
            b"mutate_operations",
            "resource_name",
            b"resource_name",
            "sequence_token",
            b"sequence_token",
        ],
    ) -> None: ...

global___AddBatchJobOperationsRequest = AddBatchJobOperationsRequest

class AddBatchJobOperationsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    TOTAL_OPERATIONS_FIELD_NUMBER: builtins.int
    NEXT_SEQUENCE_TOKEN_FIELD_NUMBER: builtins.int
    total_operations: builtins.int = ...
    next_sequence_token: typing.Text = ...
    def __init__(
        self,
        *,
        total_operations: builtins.int = ...,
        next_sequence_token: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "next_sequence_token",
            b"next_sequence_token",
            "total_operations",
            b"total_operations",
        ],
    ) -> None: ...

global___AddBatchJobOperationsResponse = AddBatchJobOperationsResponse

class ListBatchJobResultsRequest(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    PAGE_TOKEN_FIELD_NUMBER: builtins.int
    PAGE_SIZE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    page_token: typing.Text = ...
    page_size: builtins.int = ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        page_token: typing.Text = ...,
        page_size: builtins.int = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "page_size",
            b"page_size",
            "page_token",
            b"page_token",
            "resource_name",
            b"resource_name",
        ],
    ) -> None: ...

global___ListBatchJobResultsRequest = ListBatchJobResultsRequest

class ListBatchJobResultsResponse(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESULTS_FIELD_NUMBER: builtins.int
    NEXT_PAGE_TOKEN_FIELD_NUMBER: builtins.int
    next_page_token: typing.Text = ...
    @property
    def results(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___BatchJobResult
    ]: ...
    def __init__(
        self,
        *,
        results: typing.Optional[typing.Iterable[global___BatchJobResult]] = ...,
        next_page_token: typing.Text = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "next_page_token", b"next_page_token", "results", b"results"
        ],
    ) -> None: ...

global___ListBatchJobResultsResponse = ListBatchJobResultsResponse

class BatchJobResult(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPERATION_INDEX_FIELD_NUMBER: builtins.int
    MUTATE_OPERATION_RESPONSE_FIELD_NUMBER: builtins.int
    STATUS_FIELD_NUMBER: builtins.int
    operation_index: builtins.int = ...
    @property
    def mutate_operation_response(
        self,
    ) -> google.ads.google_ads.v5.proto.services.google_ads_service_pb2.MutateOperationResponse: ...
    @property
    def status(self) -> google.rpc.status_pb2.Status: ...
    def __init__(
        self,
        *,
        operation_index: builtins.int = ...,
        mutate_operation_response: typing.Optional[
            google.ads.google_ads.v5.proto.services.google_ads_service_pb2.MutateOperationResponse
        ] = ...,
        status: typing.Optional[google.rpc.status_pb2.Status] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "mutate_operation_response",
            b"mutate_operation_response",
            "status",
            b"status",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "mutate_operation_response",
            b"mutate_operation_response",
            "operation_index",
            b"operation_index",
            "status",
            b"status",
        ],
    ) -> None: ...

global___BatchJobResult = BatchJobResult



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class FeedItemTargetTypeEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _FeedItemTargetType(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            FeedItemTargetType.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = FeedItemTargetTypeEnum.FeedItemTargetType.V(0)
        UNKNOWN = FeedItemTargetTypeEnum.FeedItemTargetType.V(1)
        CAMPAIGN = FeedItemTargetTypeEnum.FeedItemTargetType.V(2)
        AD_GROUP = FeedItemTargetTypeEnum.FeedItemTargetType.V(3)
        CRITERION = FeedItemTargetTypeEnum.FeedItemTargetType.V(4)
    class FeedItemTargetType(metaclass=_FeedItemTargetType):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = FeedItemTargetTypeEnum.FeedItemTargetType.V(0)
    UNKNOWN = FeedItemTargetTypeEnum.FeedItemTargetType.V(1)
    CAMPAIGN = FeedItemTargetTypeEnum.FeedItemTargetType.V(2)
    AD_GROUP = FeedItemTargetTypeEnum.FeedItemTargetType.V(3)
    CRITERION = FeedItemTargetTypeEnum.FeedItemTargetType.V(4)
    def __init__(
        self,
    ) -> None: ...

global___FeedItemTargetTypeEnum = FeedItemTargetTypeEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class ResourceCountLimitExceededErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _ResourceCountLimitExceededError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            ResourceCountLimitExceededError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = (
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(0)
        )
        UNKNOWN = ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(
            1
        )
        ACCOUNT_LIMIT = (
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(2)
        )
        CAMPAIGN_LIMIT = (
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(3)
        )
        ADGROUP_LIMIT = (
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(4)
        )
        AD_GROUP_AD_LIMIT = (
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(5)
        )
        AD_GROUP_CRITERION_LIMIT = (
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(6)
        )
        SHARED_SET_LIMIT = (
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(7)
        )
        MATCHING_FUNCTION_LIMIT = (
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(8)
        )
        RESPONSE_ROW_LIMIT_EXCEEDED = (
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(9)
        )
        RESOURCE_LIMIT = (
            ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(10)
        )
    class ResourceCountLimitExceededError(metaclass=_ResourceCountLimitExceededError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(
        0
    )
    UNKNOWN = ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(1)
    ACCOUNT_LIMIT = (
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(2)
    )
    CAMPAIGN_LIMIT = (
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(3)
    )
    ADGROUP_LIMIT = (
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(4)
    )
    AD_GROUP_AD_LIMIT = (
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(5)
    )
    AD_GROUP_CRITERION_LIMIT = (
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(6)
    )
    SHARED_SET_LIMIT = (
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(7)
    )
    MATCHING_FUNCTION_LIMIT = (
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(8)
    )
    RESPONSE_ROW_LIMIT_EXCEEDED = (
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(9)
    )
    RESOURCE_LIMIT = (
        ResourceCountLimitExceededErrorEnum.ResourceCountLimitExceededError.V(10)
    )
    def __init__(
        self,
    ) -> None: ...

global___ResourceCountLimitExceededErrorEnum = ResourceCountLimitExceededErrorEnum



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v4.proto.enums.keyword_match_type_pb2
import google.protobuf.descriptor
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class KeywordPlanCampaignKeyword(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RESOURCE_NAME_FIELD_NUMBER: builtins.int
    KEYWORD_PLAN_CAMPAIGN_FIELD_NUMBER: builtins.int
    ID_FIELD_NUMBER: builtins.int
    TEXT_FIELD_NUMBER: builtins.int
    MATCH_TYPE_FIELD_NUMBER: builtins.int
    NEGATIVE_FIELD_NUMBER: builtins.int
    resource_name: typing.Text = ...
    match_type: google.ads.google_ads.v4.proto.enums.keyword_match_type_pb2.KeywordMatchTypeEnum.KeywordMatchType.V = (
        ...
    )
    @property
    def keyword_plan_campaign(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def id(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    @property
    def text(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def negative(self) -> google.protobuf.wrappers_pb2.BoolValue: ...
    def __init__(
        self,
        *,
        resource_name: typing.Text = ...,
        keyword_plan_campaign: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        id: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
        text: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        match_type: google.ads.google_ads.v4.proto.enums.keyword_match_type_pb2.KeywordMatchTypeEnum.KeywordMatchType.V = ...,
        negative: typing.Optional[google.protobuf.wrappers_pb2.BoolValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "id",
            b"id",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "negative",
            b"negative",
            "text",
            b"text",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "id",
            b"id",
            "keyword_plan_campaign",
            b"keyword_plan_campaign",
            "match_type",
            b"match_type",
            "negative",
            b"negative",
            "resource_name",
            b"resource_name",
            "text",
            b"text",
        ],
    ) -> None: ...

global___KeywordPlanCampaignKeyword = KeywordPlanCampaignKeyword



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import abc
import grpc

from .conversion_adjustment_upload_service_pb2 import *

class ConversionAdjustmentUploadServiceStub:
    def __init__(self, channel: grpc.Channel) -> None: ...
    def UploadConversionAdjustments(
        self,
        request: global___UploadConversionAdjustmentsRequest,
    ) -> global___UploadConversionAdjustmentsResponse: ...

class ConversionAdjustmentUploadServiceServicer(metaclass=abc.ABCMeta):
    @abc.abstractmethod
    def UploadConversionAdjustments(
        self,
        request: global___UploadConversionAdjustmentsRequest,
        context: grpc.ServicerContext,
    ) -> global___UploadConversionAdjustmentsResponse: ...

def add_ConversionAdjustmentUploadServiceServicer_to_server(
    servicer: ConversionAdjustmentUploadServiceServicer, server: grpc.Server
) -> None: ...



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.ads.google_ads.v5.proto.enums.customer_match_upload_key_type_pb2
import google.ads.google_ads.v5.proto.enums.user_list_combined_rule_operator_pb2
import google.ads.google_ads.v5.proto.enums.user_list_crm_data_source_type_pb2
import google.ads.google_ads.v5.proto.enums.user_list_date_rule_item_operator_pb2
import google.ads.google_ads.v5.proto.enums.user_list_logical_rule_operator_pb2
import google.ads.google_ads.v5.proto.enums.user_list_number_rule_item_operator_pb2
import google.ads.google_ads.v5.proto.enums.user_list_prepopulation_status_pb2
import google.ads.google_ads.v5.proto.enums.user_list_rule_type_pb2
import google.ads.google_ads.v5.proto.enums.user_list_string_rule_item_operator_pb2
import google.protobuf.descriptor
import google.protobuf.internal.containers
import google.protobuf.message
import google.protobuf.wrappers_pb2
import typing
import typing_extensions

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class SimilarUserListInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    SEED_USER_LIST_FIELD_NUMBER: builtins.int
    @property
    def seed_user_list(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        seed_user_list: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["seed_user_list", b"seed_user_list"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["seed_user_list", b"seed_user_list"]
    ) -> None: ...

global___SimilarUserListInfo = SimilarUserListInfo

class CrmBasedUserListInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    APP_ID_FIELD_NUMBER: builtins.int
    UPLOAD_KEY_TYPE_FIELD_NUMBER: builtins.int
    DATA_SOURCE_TYPE_FIELD_NUMBER: builtins.int
    upload_key_type: google.ads.google_ads.v5.proto.enums.customer_match_upload_key_type_pb2.CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V = (
        ...
    )
    data_source_type: google.ads.google_ads.v5.proto.enums.user_list_crm_data_source_type_pb2.UserListCrmDataSourceTypeEnum.UserListCrmDataSourceType.V = (
        ...
    )
    @property
    def app_id(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        app_id: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        upload_key_type: google.ads.google_ads.v5.proto.enums.customer_match_upload_key_type_pb2.CustomerMatchUploadKeyTypeEnum.CustomerMatchUploadKeyType.V = ...,
        data_source_type: google.ads.google_ads.v5.proto.enums.user_list_crm_data_source_type_pb2.UserListCrmDataSourceTypeEnum.UserListCrmDataSourceType.V = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["app_id", b"app_id"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "app_id",
            b"app_id",
            "data_source_type",
            b"data_source_type",
            "upload_key_type",
            b"upload_key_type",
        ],
    ) -> None: ...

global___CrmBasedUserListInfo = CrmBasedUserListInfo

class UserListRuleInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RULE_TYPE_FIELD_NUMBER: builtins.int
    RULE_ITEM_GROUPS_FIELD_NUMBER: builtins.int
    rule_type: google.ads.google_ads.v5.proto.enums.user_list_rule_type_pb2.UserListRuleTypeEnum.UserListRuleType.V = (
        ...
    )
    @property
    def rule_item_groups(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___UserListRuleItemGroupInfo
    ]: ...
    def __init__(
        self,
        *,
        rule_type: google.ads.google_ads.v5.proto.enums.user_list_rule_type_pb2.UserListRuleTypeEnum.UserListRuleType.V = ...,
        rule_item_groups: typing.Optional[
            typing.Iterable[global___UserListRuleItemGroupInfo]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "rule_item_groups", b"rule_item_groups", "rule_type", b"rule_type"
        ],
    ) -> None: ...

global___UserListRuleInfo = UserListRuleInfo

class UserListRuleItemGroupInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RULE_ITEMS_FIELD_NUMBER: builtins.int
    @property
    def rule_items(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___UserListRuleItemInfo
    ]: ...
    def __init__(
        self,
        *,
        rule_items: typing.Optional[
            typing.Iterable[global___UserListRuleItemInfo]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["rule_items", b"rule_items"]
    ) -> None: ...

global___UserListRuleItemGroupInfo = UserListRuleItemGroupInfo

class UserListRuleItemInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    NAME_FIELD_NUMBER: builtins.int
    NUMBER_RULE_ITEM_FIELD_NUMBER: builtins.int
    STRING_RULE_ITEM_FIELD_NUMBER: builtins.int
    DATE_RULE_ITEM_FIELD_NUMBER: builtins.int
    @property
    def name(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def number_rule_item(self) -> global___UserListNumberRuleItemInfo: ...
    @property
    def string_rule_item(self) -> global___UserListStringRuleItemInfo: ...
    @property
    def date_rule_item(self) -> global___UserListDateRuleItemInfo: ...
    def __init__(
        self,
        *,
        name: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        number_rule_item: typing.Optional[global___UserListNumberRuleItemInfo] = ...,
        string_rule_item: typing.Optional[global___UserListStringRuleItemInfo] = ...,
        date_rule_item: typing.Optional[global___UserListDateRuleItemInfo] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "date_rule_item",
            b"date_rule_item",
            "name",
            b"name",
            "number_rule_item",
            b"number_rule_item",
            "rule_item",
            b"rule_item",
            "string_rule_item",
            b"string_rule_item",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "date_rule_item",
            b"date_rule_item",
            "name",
            b"name",
            "number_rule_item",
            b"number_rule_item",
            "rule_item",
            b"rule_item",
            "string_rule_item",
            b"string_rule_item",
        ],
    ) -> None: ...
    def WhichOneof(
        self, oneof_group: typing_extensions.Literal["rule_item", b"rule_item"]
    ) -> typing_extensions.Literal[
        "number_rule_item", "string_rule_item", "date_rule_item"
    ]: ...

global___UserListRuleItemInfo = UserListRuleItemInfo

class UserListDateRuleItemInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPERATOR_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    OFFSET_IN_DAYS_FIELD_NUMBER: builtins.int
    operator: google.ads.google_ads.v5.proto.enums.user_list_date_rule_item_operator_pb2.UserListDateRuleItemOperatorEnum.UserListDateRuleItemOperator.V = (
        ...
    )
    @property
    def value(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def offset_in_days(self) -> google.protobuf.wrappers_pb2.Int64Value: ...
    def __init__(
        self,
        *,
        operator: google.ads.google_ads.v5.proto.enums.user_list_date_rule_item_operator_pb2.UserListDateRuleItemOperatorEnum.UserListDateRuleItemOperator.V = ...,
        value: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        offset_in_days: typing.Optional[google.protobuf.wrappers_pb2.Int64Value] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "offset_in_days", b"offset_in_days", "value", b"value"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "offset_in_days",
            b"offset_in_days",
            "operator",
            b"operator",
            "value",
            b"value",
        ],
    ) -> None: ...

global___UserListDateRuleItemInfo = UserListDateRuleItemInfo

class UserListNumberRuleItemInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPERATOR_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    operator: google.ads.google_ads.v5.proto.enums.user_list_number_rule_item_operator_pb2.UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V = (
        ...
    )
    @property
    def value(self) -> google.protobuf.wrappers_pb2.DoubleValue: ...
    def __init__(
        self,
        *,
        operator: google.ads.google_ads.v5.proto.enums.user_list_number_rule_item_operator_pb2.UserListNumberRuleItemOperatorEnum.UserListNumberRuleItemOperator.V = ...,
        value: typing.Optional[google.protobuf.wrappers_pb2.DoubleValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["value", b"value"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "operator", b"operator", "value", b"value"
        ],
    ) -> None: ...

global___UserListNumberRuleItemInfo = UserListNumberRuleItemInfo

class UserListStringRuleItemInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPERATOR_FIELD_NUMBER: builtins.int
    VALUE_FIELD_NUMBER: builtins.int
    operator: google.ads.google_ads.v5.proto.enums.user_list_string_rule_item_operator_pb2.UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V = (
        ...
    )
    @property
    def value(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        operator: google.ads.google_ads.v5.proto.enums.user_list_string_rule_item_operator_pb2.UserListStringRuleItemOperatorEnum.UserListStringRuleItemOperator.V = ...,
        value: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["value", b"value"]
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "operator", b"operator", "value", b"value"
        ],
    ) -> None: ...

global___UserListStringRuleItemInfo = UserListStringRuleItemInfo

class CombinedRuleUserListInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    LEFT_OPERAND_FIELD_NUMBER: builtins.int
    RIGHT_OPERAND_FIELD_NUMBER: builtins.int
    RULE_OPERATOR_FIELD_NUMBER: builtins.int
    rule_operator: google.ads.google_ads.v5.proto.enums.user_list_combined_rule_operator_pb2.UserListCombinedRuleOperatorEnum.UserListCombinedRuleOperator.V = (
        ...
    )
    @property
    def left_operand(self) -> global___UserListRuleInfo: ...
    @property
    def right_operand(self) -> global___UserListRuleInfo: ...
    def __init__(
        self,
        *,
        left_operand: typing.Optional[global___UserListRuleInfo] = ...,
        right_operand: typing.Optional[global___UserListRuleInfo] = ...,
        rule_operator: google.ads.google_ads.v5.proto.enums.user_list_combined_rule_operator_pb2.UserListCombinedRuleOperatorEnum.UserListCombinedRuleOperator.V = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "left_operand", b"left_operand", "right_operand", b"right_operand"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "left_operand",
            b"left_operand",
            "right_operand",
            b"right_operand",
            "rule_operator",
            b"rule_operator",
        ],
    ) -> None: ...

global___CombinedRuleUserListInfo = CombinedRuleUserListInfo

class DateSpecificRuleUserListInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RULE_FIELD_NUMBER: builtins.int
    START_DATE_FIELD_NUMBER: builtins.int
    END_DATE_FIELD_NUMBER: builtins.int
    @property
    def rule(self) -> global___UserListRuleInfo: ...
    @property
    def start_date(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def end_date(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        rule: typing.Optional[global___UserListRuleInfo] = ...,
        start_date: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
        end_date: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "end_date", b"end_date", "rule", b"rule", "start_date", b"start_date"
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "end_date", b"end_date", "rule", b"rule", "start_date", b"start_date"
        ],
    ) -> None: ...

global___DateSpecificRuleUserListInfo = DateSpecificRuleUserListInfo

class ExpressionRuleUserListInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RULE_FIELD_NUMBER: builtins.int
    @property
    def rule(self) -> global___UserListRuleInfo: ...
    def __init__(
        self,
        *,
        rule: typing.Optional[global___UserListRuleInfo] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["rule", b"rule"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["rule", b"rule"]
    ) -> None: ...

global___ExpressionRuleUserListInfo = ExpressionRuleUserListInfo

class RuleBasedUserListInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    PREPOPULATION_STATUS_FIELD_NUMBER: builtins.int
    COMBINED_RULE_USER_LIST_FIELD_NUMBER: builtins.int
    DATE_SPECIFIC_RULE_USER_LIST_FIELD_NUMBER: builtins.int
    EXPRESSION_RULE_USER_LIST_FIELD_NUMBER: builtins.int
    prepopulation_status: google.ads.google_ads.v5.proto.enums.user_list_prepopulation_status_pb2.UserListPrepopulationStatusEnum.UserListPrepopulationStatus.V = (
        ...
    )
    @property
    def combined_rule_user_list(self) -> global___CombinedRuleUserListInfo: ...
    @property
    def date_specific_rule_user_list(self) -> global___DateSpecificRuleUserListInfo: ...
    @property
    def expression_rule_user_list(self) -> global___ExpressionRuleUserListInfo: ...
    def __init__(
        self,
        *,
        prepopulation_status: google.ads.google_ads.v5.proto.enums.user_list_prepopulation_status_pb2.UserListPrepopulationStatusEnum.UserListPrepopulationStatus.V = ...,
        combined_rule_user_list: typing.Optional[
            global___CombinedRuleUserListInfo
        ] = ...,
        date_specific_rule_user_list: typing.Optional[
            global___DateSpecificRuleUserListInfo
        ] = ...,
        expression_rule_user_list: typing.Optional[
            global___ExpressionRuleUserListInfo
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "combined_rule_user_list",
            b"combined_rule_user_list",
            "date_specific_rule_user_list",
            b"date_specific_rule_user_list",
            "expression_rule_user_list",
            b"expression_rule_user_list",
            "rule_based_user_list",
            b"rule_based_user_list",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "combined_rule_user_list",
            b"combined_rule_user_list",
            "date_specific_rule_user_list",
            b"date_specific_rule_user_list",
            "expression_rule_user_list",
            b"expression_rule_user_list",
            "prepopulation_status",
            b"prepopulation_status",
            "rule_based_user_list",
            b"rule_based_user_list",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal[
            "rule_based_user_list", b"rule_based_user_list"
        ],
    ) -> typing_extensions.Literal[
        "combined_rule_user_list",
        "date_specific_rule_user_list",
        "expression_rule_user_list",
    ]: ...

global___RuleBasedUserListInfo = RuleBasedUserListInfo

class LogicalUserListInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    RULES_FIELD_NUMBER: builtins.int
    @property
    def rules(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___UserListLogicalRuleInfo
    ]: ...
    def __init__(
        self,
        *,
        rules: typing.Optional[typing.Iterable[global___UserListLogicalRuleInfo]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["rules", b"rules"]
    ) -> None: ...

global___LogicalUserListInfo = LogicalUserListInfo

class UserListLogicalRuleInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    OPERATOR_FIELD_NUMBER: builtins.int
    RULE_OPERANDS_FIELD_NUMBER: builtins.int
    operator: google.ads.google_ads.v5.proto.enums.user_list_logical_rule_operator_pb2.UserListLogicalRuleOperatorEnum.UserListLogicalRuleOperator.V = (
        ...
    )
    @property
    def rule_operands(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___LogicalUserListOperandInfo
    ]: ...
    def __init__(
        self,
        *,
        operator: google.ads.google_ads.v5.proto.enums.user_list_logical_rule_operator_pb2.UserListLogicalRuleOperatorEnum.UserListLogicalRuleOperator.V = ...,
        rule_operands: typing.Optional[
            typing.Iterable[global___LogicalUserListOperandInfo]
        ] = ...,
    ) -> None: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "operator", b"operator", "rule_operands", b"rule_operands"
        ],
    ) -> None: ...

global___UserListLogicalRuleInfo = UserListLogicalRuleInfo

class LogicalUserListOperandInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    USER_LIST_FIELD_NUMBER: builtins.int
    @property
    def user_list(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        user_list: typing.Optional[google.protobuf.wrappers_pb2.StringValue] = ...,
    ) -> None: ...
    def HasField(
        self, field_name: typing_extensions.Literal["user_list", b"user_list"]
    ) -> builtins.bool: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["user_list", b"user_list"]
    ) -> None: ...

global___LogicalUserListOperandInfo = LogicalUserListOperandInfo

class BasicUserListInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    ACTIONS_FIELD_NUMBER: builtins.int
    @property
    def actions(
        self,
    ) -> google.protobuf.internal.containers.RepeatedCompositeFieldContainer[
        global___UserListActionInfo
    ]: ...
    def __init__(
        self,
        *,
        actions: typing.Optional[typing.Iterable[global___UserListActionInfo]] = ...,
    ) -> None: ...
    def ClearField(
        self, field_name: typing_extensions.Literal["actions", b"actions"]
    ) -> None: ...

global___BasicUserListInfo = BasicUserListInfo

class UserListActionInfo(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    CONVERSION_ACTION_FIELD_NUMBER: builtins.int
    REMARKETING_ACTION_FIELD_NUMBER: builtins.int
    @property
    def conversion_action(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    @property
    def remarketing_action(self) -> google.protobuf.wrappers_pb2.StringValue: ...
    def __init__(
        self,
        *,
        conversion_action: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
        remarketing_action: typing.Optional[
            google.protobuf.wrappers_pb2.StringValue
        ] = ...,
    ) -> None: ...
    def HasField(
        self,
        field_name: typing_extensions.Literal[
            "conversion_action",
            b"conversion_action",
            "remarketing_action",
            b"remarketing_action",
            "user_list_action",
            b"user_list_action",
        ],
    ) -> builtins.bool: ...
    def ClearField(
        self,
        field_name: typing_extensions.Literal[
            "conversion_action",
            b"conversion_action",
            "remarketing_action",
            b"remarketing_action",
            "user_list_action",
            b"user_list_action",
        ],
    ) -> None: ...
    def WhichOneof(
        self,
        oneof_group: typing_extensions.Literal["user_list_action", b"user_list_action"],
    ) -> typing_extensions.Literal["conversion_action", "remarketing_action"]: ...

global___UserListActionInfo = UserListActionInfo



"""
@generated by mypy-protobuf.  Do not edit manually!
isort:skip_file
"""
import builtins
import google.protobuf.descriptor
import google.protobuf.internal.enum_type_wrapper
import google.protobuf.message
import typing

DESCRIPTOR: google.protobuf.descriptor.FileDescriptor = ...

class CampaignDraftErrorEnum(google.protobuf.message.Message):
    DESCRIPTOR: google.protobuf.descriptor.Descriptor = ...
    class _CampaignDraftError(
        google.protobuf.internal.enum_type_wrapper._EnumTypeWrapper[
            CampaignDraftError.V
        ],
        builtins.type,
    ):
        DESCRIPTOR: google.protobuf.descriptor.EnumDescriptor = ...
        UNSPECIFIED = CampaignDraftErrorEnum.CampaignDraftError.V(0)
        UNKNOWN = CampaignDraftErrorEnum.CampaignDraftError.V(1)
        DUPLICATE_DRAFT_NAME = CampaignDraftErrorEnum.CampaignDraftError.V(2)
        INVALID_STATUS_TRANSITION_FROM_REMOVED = (
            CampaignDraftErrorEnum.CampaignDraftError.V(3)
        )
        INVALID_STATUS_TRANSITION_FROM_PROMOTED = (
            CampaignDraftErrorEnum.CampaignDraftError.V(4)
        )
        INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED = (
            CampaignDraftErrorEnum.CampaignDraftError.V(5)
        )
        CUSTOMER_CANNOT_CREATE_DRAFT = CampaignDraftErrorEnum.CampaignDraftError.V(6)
        CAMPAIGN_CANNOT_CREATE_DRAFT = CampaignDraftErrorEnum.CampaignDraftError.V(7)
        INVALID_DRAFT_CHANGE = CampaignDraftErrorEnum.CampaignDraftError.V(8)
        INVALID_STATUS_TRANSITION = CampaignDraftErrorEnum.CampaignDraftError.V(9)
        MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED = (
            CampaignDraftErrorEnum.CampaignDraftError.V(10)
        )
        LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY = (
            CampaignDraftErrorEnum.CampaignDraftError.V(11)
        )
    class CampaignDraftError(metaclass=_CampaignDraftError):
        V = typing.NewType("V", builtins.int)
    UNSPECIFIED = CampaignDraftErrorEnum.CampaignDraftError.V(0)
    UNKNOWN = CampaignDraftErrorEnum.CampaignDraftError.V(1)
    DUPLICATE_DRAFT_NAME = CampaignDraftErrorEnum.CampaignDraftError.V(2)
    INVALID_STATUS_TRANSITION_FROM_REMOVED = (
        CampaignDraftErrorEnum.CampaignDraftError.V(3)
    )
    INVALID_STATUS_TRANSITION_FROM_PROMOTED = (
        CampaignDraftErrorEnum.CampaignDraftError.V(4)
    )
    INVALID_STATUS_TRANSITION_FROM_PROMOTE_FAILED = (
        CampaignDraftErrorEnum.CampaignDraftError.V(5)
    )
    CUSTOMER_CANNOT_CREATE_DRAFT = CampaignDraftErrorEnum.CampaignDraftError.V(6)
    CAMPAIGN_CANNOT_CREATE_DRAFT = CampaignDraftErrorEnum.CampaignDraftError.V(7)
    INVALID_DRAFT_CHANGE = CampaignDraftErrorEnum.CampaignDraftError.V(8)
    INVALID_STATUS_TRANSITION = CampaignDraftErrorEnum.CampaignDraftError.V(9)
    MAX_NUMBER_OF_DRAFTS_PER_CAMPAIGN_REACHED = (
        CampaignDraftErrorEnum.CampaignDraftError.V(10)
    )
    LIST_ERRORS_FOR_PROMOTED_DRAFT_ONLY = CampaignDraftErrorEnum.CampaignDraftError.V(
        11
    )
    def __init__(
        self,
    ) -> None: ...

global___CampaignDraftErrorEnum = CampaignDraftErrorEnum
